@@ -53,7 +53,7 @@ use Carp;
 use Data::Dumper;
 
 use fields qw(	_title
-		_kind
+				_kind
 				_year
 				_episodes
 				_episodeof
@@ -91,7 +91,7 @@ use constant EMPTY_OBJECT	=> 0;
 use constant MAIN_TAG		=> 'h5';
 
 BEGIN {
-		$VERSION = '0.32';
+		$VERSION = '0.35';
 						
 		# Convert age gradation to the digits		
 		# TODO: Store this info into constant file
@@ -422,11 +422,12 @@ sub episodes {
 
 		my $parser = $self->_parser(FORCED, \$page);
 		while(my $tag = $parser->get_tag('a')) {
+			my $id;
 			next unless $tag->[1]->{name} and $tag->[1]->{name} =~ /year/;
 			$parser->get_tag('h4');
 			my($season, $episode) = $parser->get_text =~ /Season\s+(.*?),\s+Episode\s+([^:]+)/;
 			my $imdb_tag = $parser->get_tag('a');
-			my($id) = $imdb_tag->[1]->{href} =~ /(\d+)/;
+			($id) = $imdb_tag->[1]->{href} =~ /(\d+)/ if $imdb_tag->[1]->{href};
 			my $title = $parser->get_trimmed_text;
 			$parser->get_tag('b');
 			my($date) = $parser->get_trimmed_text =~ /Original Air Date:\s+(.*)/;
@@ -703,14 +704,16 @@ sub rating {
 	if($forced) {
 		my $parser = $self->_parser(FORCED);
 	
-		while(my $tag = $parser->get_tag('b')) {
-			last if $parser->get_text =~ /rating/i;
+		while(my $tag = $parser->get_tag(MAIN_TAG)) {
+			last if $parser->get_text =~ /^User Rating/i;
 		}
 		
 		my $tag = $parser->get_tag('b');	
 		my $text = $parser->get_trimmed_text('b', '/a');
 
-		my($rating, $val) = $text =~ m!(\d*\.?\d*)\/.*?\((\d*\,?\d*)\s.*?\)?!;
+		$self->_show_message("Rating text is [$text]; tag: " . Dumper($tag), 'DEBUG');
+
+		my($rating, $val) = $text =~ m!(\d+\.?\d*)/10.*?(\d+,?\d*)!;
 		$val =~ s/\,// if $val;
 
 		$self->{_rating} = [$rating, $val];
@@ -784,7 +787,7 @@ sub duration {
 			last if $text =~ /runtime:/i;
 		}	
 		
-		my @runtime = split /\s+\/\s+/, $parser->get_trimmed_text(MAIN_TAG, 'br');
+		my @runtime = split /\s+(\/|\|)\s+/, $parser->get_trimmed_text(MAIN_TAG, 'br');
 		
 		$self->{_duration} = \@runtime;		
 	}
@@ -796,7 +799,7 @@ sub duration {
 
 Retrieve film produced countries list:
 
-	my @countries = $film->country();
+	my $countries = $film->country();
 
 =cut
 sub country {
@@ -811,9 +814,11 @@ sub country {
 
 		my (@countries);
 		while(my $tag = $parser->get_tag()) {
-			
+
 			if( $tag->[0] eq 'a' && $tag->[1]{href} && $tag->[1]{href} =~ /countries/i ) {
-				push @countries, $parser->get_text();
+				my $text = $parser->get_text();
+				$text =~ s/\n//g;
+				push @countries, $text;
 			} 
 			
 			last if $tag->[0] eq 'br';
@@ -829,7 +834,7 @@ sub country {
 
 Retrieve film languages list:
 
-	my @languages = $film->language();
+	my $languages = $film->language();
 
 =cut
 sub language {
@@ -846,7 +851,9 @@ sub language {
 		while($tag = $parser->get_tag()) {
 			
 			if( $tag->[0] eq 'a' && $tag->[1]{href} && $tag->[1]{href} =~ /languages/i ) {
-				push @languages, $parser->get_text();
+				my $text = $parser->get_text();
+				$text =~ s/\n//g;
+				push @languages, $text;
 			} 
 			
 			last if $tag->[0] eq 'br';
@@ -995,7 +1002,9 @@ sub certifications {
 		while($tag = $parser->get_tag()) {
 			
 			if($tag->[0] eq 'a' && $tag->[1]{href} && $tag->[1]{href} =~ /certificates/i) {
-				my($country, $range) = split /\:/, $parser->get_text;
+				my $text = $parser->get_text();
+				$text =~ s/\n//g;
+				my($country, $range) = split /\:/, $text;
 				$cert_list{$country} = $range;
 			}
 
@@ -1132,7 +1141,6 @@ sub release_dates {
 
 		my $parser = $self->_parser(FORCED, \$page);
 		while(my $tag = $parser->get_tag('th')) {
-			#last if $tag->[1]->{id} && $tag->[1]->{id} eq 'tn15title';
 			last if $tag->[1]->{class} && $tag->[1]->{class} eq 'xxxx';
 		}
 
@@ -1145,6 +1153,8 @@ sub release_dates {
 			my $year_tag = $parser->get_tag('a');
 			my $year = $parser->get_text;
 
+			$self->_show_message("country=$country; date=$date, $year", 'DEBUG');
+
 			push @{ $self->{_release_dates} }, {country => $country, date => "$date, $year"};
 		}
 	}
